@@ -182,7 +182,7 @@ if ( 1 == 0 )    ## - validate user scope for an api service endpoint string - i
   #print Dumper $foo;exit;
   ## list all user scopes configured
 
-  my $configured_scopes = $gapi_agent->get_scopes_as_array();    ## TODO rename to array_ref
+  my $configured_scopes = $gapi_agent->scopes;
   say "Scopes currently configured are: \n * " . join( "\n * ", @$configured_scopes );
   ## transform list into a hash so can do instant lookups
 
@@ -229,7 +229,6 @@ if ( 1 == 0 )    ## - validate user scope for an api service endpoint string - i
 ######################################
 
 
-
 #print ;exit;
 ######################################
 if ( 1 == 1 )                               ## TODO: - Audit all service method param
@@ -366,11 +365,6 @@ if ( 1 == 0 )    ## TODO: - explore interpolation of variables
 ######################################
 
 
-# my $api_verson_urls = api_version_urls(); ## hash of api discovery urls api->version->url .. bugger deleted this function
-#print Dumper $api_verson_urls ;
-#my $api = 'appengine'; my $version = 'v1beta5';
-#my $api = 'sheets'; my $version = 'v4';
-#my $api = 'sheets'; my $version = '';
 my $api     = 'gmail';
 my $version = 'v1';
 
@@ -466,7 +460,6 @@ for my $api ( @{ $aapis } )
 exit;
 
 
-print WebService::GoogleAPI::Client::Discovery->new->supported_as_text();
 exit;
 
 
